@@ -64,17 +64,6 @@ struct mail_storage_settings {
 	const char *hostname;
 	const char *recipient_delimiter;
 
-	const char *ssl_client_ca_file;
-	const char *ssl_client_ca_dir;
-	const char *ssl_client_cert;
-	const char *ssl_client_key;
-	const char *ssl_cipher_list;
-	const char *ssl_cipher_suites;
-	const char *ssl_curve_list;
-	const char *ssl_min_protocol;
-	const char *ssl_crypto_device;
-	bool ssl_client_require_valid_cert;
-	bool verbose_ssl;
 	const char *mail_attachment_detection_options;
 
 	enum file_lock_method parsed_lock_method;
@@ -183,7 +172,4 @@ bool mail_user_set_get_postmaster_smtp(const struct mail_user_settings *set,
 				       const struct smtp_address **address_r,
 				       const char **error_r);
 
-void mail_storage_settings_init_ssl_client_settings(const struct mail_storage_settings *mail_set,
-						    struct ssl_iostream_settings *ssl_set_r);
-
 #endif
